@@ -34,7 +34,11 @@ class Enviar(object):
     #FIXME: rever isso ao refatorar o sistema de pedido
     @property
     def valor_envio(self):
-        return self.pedido.valor_total - self.pedido.valor_subtotal
+        return self.pedido.valor_total - self.pedido.valor_subtotal + self.pedido.valor_desconto
+
+    @property
+    def valor_desconto(self):
+        return self.pedido.valor_desconto
 
 
 class EnviarPedido(Plugavel):
